.. _installation_nightly:

Nightly
=======

The nightly channel contains the most recent updates of the project.
As described in the :ref:`support policy <support_policy>`, this channel requires building Ignition from sources.

We publish updated nightly packages after any pull request merged in the ``devel`` branch.

.. include:: virtual_environment.rst

PyPI Package
************

Install the pre-release `gym-ignition <https://pypi.org/project/gym-ignition/>`_ package from PyPI:

.. code-block:: bash

   pip install --pre gym-ignition

.. include:: system_configuration.rst
